=====================
Django Nomad Notifier
=====================

Overview
========

This Django app provides a way to implement a **notification system** for
the users of web apps that must receive updates from the site activity
through the following channels:

* **Email notifications**: they call them *transactional emails* nowadays.
  Messages like "Hi Frankie, Jimbo is now following you on SomeSocialFoo.com".
* **Web notifications**: displayed/listed on UI ("ala" social apps such as
  Facebook or Google+). A list of notifications that can be marked as read.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage

